==> apimaticcalculatorpythonv6Demo-1.0.0.tar.gz: apimaticcalculatorpythonv6Demo-1.0.0/README.md <==
# Getting started

Simple calculator API hosted on APIMATIC

## How to Build


You must have Python ```2 >=2.7.9``` or Python ```3 >=3.4``` installed on your system to install and run this SDK. This SDK package depends on other Python packages like nose, jsonpickle etc. 
These dependencies are defined in the ```requirements.txt``` file that comes with the SDK.
To resolve these dependencies, you can use the PIP Dependency manager. Install it by following steps at [https://pip.pypa.io/en/stable/installing/](https://pip.pypa.io/en/stable/installing/).

Python and PIP executables should be defined in your PATH. Open command prompt and type ```pip --version```.
This should display the version of the PIP Dependency Manager installed if your installation was successful and the paths are properly defined.

* Using command line, navigate to the directory containing the generated files (including ```requirements.txt```) for the SDK.
* Run the command ```pip install -r requirements.txt```. This should install all the required dependencies.

![Building SDK - Step 1](https://apidocs.io/illustration/python?step=installDependencies&workspaceFolder=APIMATIC%20Calculator-Python)


## How to Use

The following section explains how to use the Apimaticcalculator SDK package in a new project.

### 1. Open Project in an IDE

Open up a Python IDE like PyCharm. The basic workflow presented here is also applicable if you prefer using a different editor or IDE.

![Open project in PyCharm - Step 1](https://apidocs.io/illustration/python?step=pyCharm)

Click on ```Open``` in PyCharm to browse to your generated SDK directory and then click ```OK```.

![Open project in PyCharm - Step 2](https://apidocs.io/illustration/python?step=openProject0&workspaceFolder=APIMATIC%20Calculator-Python)     

The project files will be displayed in the side bar as follows:

![Open project in PyCharm - Step 3](https://apidocs.io/illustration/python?step=openProject1&workspaceFolder=APIMATIC%20Calculator-Python&projectName=apimaticcalculatorpythonv6demo)     

### 2. Add a new Test Project

Create a new directory by right clicking on the solution name as shown below:

![Add a new project in PyCharm - Step 1](https://apidocs.io/illustration/python?step=createDirectory&workspaceFolder=APIMATIC%20Calculator-Python&projectName=apimaticcalculatorpythonv6demo)

Name the directory as "test"

![Add a new project in PyCharm - Step 2](https://apidocs.io/illustration/python?step=nameDirectory)
   
Add a python file to this project with the name "testsdk"

![Add a new project in PyCharm - Step 3](https://apidocs.io/illustration/python?step=createFile&workspaceFolder=APIMATIC%20Calculator-Python&projectName=apimaticcalculatorpythonv6demo)

Name it "testsdk"

![Add a new project in PyCharm - Step 4](https://apidocs.io/illustration/python?step=nameFile)

In your python file you will be required to import the generated python library using the following code lines

```Python
from apimaticcalculatorpythonv6demo.apimaticcalculatorpythonv6_demo_client import Apimaticcalculatorpythonv6DemoClient
```

![Add a new project in PyCharm - Step 4](https://apidocs.io/illustration/python?step=projectFiles&workspaceFolder=APIMATIC%20Calculator-Python&libraryName=apimaticcalculatorpythonv6demo.apimaticcalculatorpythonv6_demo_client&projectName=apimaticcalculatorpythonv6demo&className=Apimaticcalculatorpythonv6DemoClient)

After this you can write code to instantiate an API client object, get a controller object and  make API calls. Sample code is given in the subsequent sections.

### 3. Run the Test Project

To run the file within your test project, right click on your Python file inside your Test project and click on ```Run```

![Run Test Project - Step 1](https://apidocs.io/illustration/python?step=runProject&workspaceFolder=APIMATIC%20Calculator-Python&libraryName=apimaticcalculatorpythonv6demo.apimaticcalculatorpythonv6_demo_client&projectName=apimaticcalculatorpythonv6demo&className=Apimaticcalculatorpythonv6DemoClient)


## How to Test

You can test the generated SDK and the server with automatically generated test
cases. unittest is used as the testing framework and nose is used as the test
runner. You can run the tests as follows:

  1. From terminal/cmd navigate to the root directory of the SDK.
  2. Invoke ```pip install -r test-requirements.txt```
  3. Invoke ```nosetests```

## Initialization

### 

API client can be initialized as following.

```python

client = Apimaticcalculatorpythonv6DemoClient()
```



# Class Reference

## <a name="list_of_controllers"></a>List of Controllers

* [CalculatorDevOpsConf](#calculator_dev_ops_conf)

## <a name="calculator_dev_ops_conf"></a>![Class: ](https://apidocs.io/img/class.png ".CalculatorDevOpsConf") CalculatorDevOpsConf

### Get controller instance

An instance of the ``` CalculatorDevOpsConf ``` class can be accessed from the API Client.

```python
 calculator_dev_ops_conf_controller = client.calculator_dev_ops_conf
```

### <a name="calculate_dev_ops_stamford"></a>![Method: ](https://apidocs.io/img/method.png ".CalculatorDevOpsConf.calculate_dev_ops_stamford") calculate_dev_ops_stamford

> Calculates the expression using the specified operation..

```python
def calculate_dev_ops_stamford(self,
                                   operation,
                                   x,
                                   y)
```

#### Parameters

| Parameter | Tags | Description |
|-----------|------|-------------|
| operation |  ``` Required ```  | The operator to apply on the variables |
| x |  ``` Required ```  | The LHS value |
| y |  ``` Required ```  | The RHS value |



#### Example Usage

```python
operation = OperationType.MULTIPLY
x = 4
y = 5

result = calculator_dev_ops_conf_controller.calculate_dev_ops_stamford(operation, x, y)

```


[Back to List of Controllers](#list_of_controllers)

==> apimaticcalculatorpythonv6Demo-1.0.2.tar.gz: apimaticcalculatorpythonv6Demo-1.0.2/README.md <==
# Getting started

Simple calculator API hosted on APIMATIC

## How to Build


You must have Python ```2 >=2.7.9``` or Python ```3 >=3.4``` installed on your system to install and run this SDK. This SDK package depends on other Python packages like nose, jsonpickle etc. 
These dependencies are defined in the ```requirements.txt``` file that comes with the SDK.
To resolve these dependencies, you can use the PIP Dependency manager. Install it by following steps at [https://pip.pypa.io/en/stable/installing/](https://pip.pypa.io/en/stable/installing/).

Python and PIP executables should be defined in your PATH. Open command prompt and type ```pip --version```.
This should display the version of the PIP Dependency Manager installed if your installation was successful and the paths are properly defined.

* Using command line, navigate to the directory containing the generated files (including ```requirements.txt```) for the SDK.
* Run the command ```pip install -r requirements.txt```. This should install all the required dependencies.

![Building SDK - Step 1](https://apidocs.io/illustration/python?step=installDependencies&workspaceFolder=APIMATIC%20Calculator-Python)


## How to Use

The following section explains how to use the Apimaticcalculatorpythonv6Demo SDK package in a new project.

### 1. Open Project in an IDE

Open up a Python IDE like PyCharm. The basic workflow presented here is also applicable if you prefer using a different editor or IDE.

![Open project in PyCharm - Step 1](https://apidocs.io/illustration/python?step=pyCharm)

Click on ```Open``` in PyCharm to browse to your generated SDK directory and then click ```OK```.

![Open project in PyCharm - Step 2](https://apidocs.io/illustration/python?step=openProject0&workspaceFolder=APIMATIC%20Calculator-Python)     

The project files will be displayed in the side bar as follows:

![Open project in PyCharm - Step 3](https://apidocs.io/illustration/python?step=openProject1&workspaceFolder=APIMATIC%20Calculator-Python&projectName=apimaticcalculatorpythonv6_demo)     

### 2. Add a new Test Project

Create a new directory by right clicking on the solution name as shown below:

![Add a new project in PyCharm - Step 1](https://apidocs.io/illustration/python?step=createDirectory&workspaceFolder=APIMATIC%20Calculator-Python&projectName=apimaticcalculatorpythonv6_demo)

Name the directory as "test"

![Add a new project in PyCharm - Step 2](https://apidocs.io/illustration/python?step=nameDirectory)
   
Add a python file to this project with the name "testsdk"

![Add a new project in PyCharm - Step 3](https://apidocs.io/illustration/python?step=createFile&workspaceFolder=APIMATIC%20Calculator-Python&projectName=apimaticcalculatorpythonv6_demo)

Name it "testsdk"

![Add a new project in PyCharm - Step 4](https://apidocs.io/illustration/python?step=nameFile)

In your python file you will be required to import the generated python library using the following code lines

```Python
from apimaticcalculatorpythonv6_demo.apimaticcalculatorpythonv6_demo_client import Apimaticcalculatorpythonv6DemoClient
```

![Add a new project in PyCharm - Step 4](https://apidocs.io/illustration/python?step=projectFiles&workspaceFolder=APIMATIC%20Calculator-Python&libraryName=apimaticcalculatorpythonv6_demo.apimaticcalculatorpythonv6_demo_client&projectName=apimaticcalculatorpythonv6_demo&className=Apimaticcalculatorpythonv6DemoClient)

After this you can write code to instantiate an API client object, get a controller object and  make API calls. Sample code is given in the subsequent sections.

### 3. Run the Test Project

To run the file within your test project, right click on your Python file inside your Test project and click on ```Run```

![Run Test Project - Step 1](https://apidocs.io/illustration/python?step=runProject&workspaceFolder=APIMATIC%20Calculator-Python&libraryName=apimaticcalculatorpythonv6_demo.apimaticcalculatorpythonv6_demo_client&projectName=apimaticcalculatorpythonv6_demo&className=Apimaticcalculatorpythonv6DemoClient)


## How to Test

You can test the generated SDK and the server with automatically generated test
cases. unittest is used as the testing framework and nose is used as the test
runner. You can run the tests as follows:

  1. From terminal/cmd navigate to the root directory of the SDK.
  2. Invoke ```pip install -r test-requirements.txt```
  3. Invoke ```nosetests```

## Initialization

### 

API client can be initialized as following.

```python

client = Apimaticcalculatorpythonv6DemoClient()
```



# Class Reference

## <a name="list_of_controllers"></a>List of Controllers

* [CalculatorDevOpsConf](#calculator_dev_ops_conf)

## <a name="calculator_dev_ops_conf"></a>![Class: ](https://apidocs.io/img/class.png ".CalculatorDevOpsConf") CalculatorDevOpsConf

### Get controller instance

An instance of the ``` CalculatorDevOpsConf ``` class can be accessed from the API Client.

```python
 calculator_dev_ops_conf_controller = client.calculator_dev_ops_conf
```

### <a name="calculate_dev_ops_stamford"></a>![Method: ](https://apidocs.io/img/method.png ".CalculatorDevOpsConf.calculate_dev_ops_stamford") calculate_dev_ops_stamford

> Calculates the expression using the specified operation..

```python
def calculate_dev_ops_stamford(self,
                                   operation,
                                   x,
                                   y)
```

#### Parameters

| Parameter | Tags | Description |
|-----------|------|-------------|
| operation |  ``` Required ```  | The operator to apply on the variables |
| x |  ``` Required ```  | The LHS value |
| y |  ``` Required ```  | The RHS value |



#### Example Usage

```python
operation = OperationType.DIVIDE
x = 20
y = 4

result = calculator_dev_ops_conf_controller.calculate_dev_ops_stamford(operation, x, y)

```


[Back to List of Controllers](#list_of_controllers)
